import { Component, OnInit } from '@angular/core';
import { NotificationService } from '../../../services/notification.service';
import { StructureAdminInfo } from '../../models/demandAttachment.model';
import { AdminService } from '../../services/admin.service';

@Component({
  selector: 'app-admin-claim-structure',
  templateUrl: './claim-structure.component.html',
  styleUrls: ['../../admin-pannel.scss'],
})
export class ClaimStructureComponent implements OnInit {
  public demandsAttachment: StructureAdminInfo[];
  public structuresUnclaimed: StructureAdminInfo[];
  public isClaimedStructure: boolean = true;
  public isUnclaimedStructure: boolean = false;
  constructor(private adminService: AdminService, private notificationService: NotificationService) {}

  ngOnInit(): void {
    this.adminService.getPendingStructure().subscribe((demands) => {
      this.demandsAttachment = demands;
    });
  }

  public acceptDemand(demand: StructureAdminInfo): void {
    this.adminService.acceptStructureClaim(demand.userEmail, demand.structureId, demand.structureName).subscribe({
      next: (data) => {
        this.demandsAttachment = data;
        this.notificationService.showSuccess('Demande acceptée avec succès');
      },
      error: (e) => {
        this.notificationService.showError('Une erreur est survenue');
      },
    });
  }

  public refuseDemand(demand: StructureAdminInfo): void {
    this.adminService.refuseStructureClaim(demand.userEmail, demand.structureId, demand.structureName).subscribe({
      next: (data) => {
        this.demandsAttachment = data;
        this.notificationService.showSuccess('Demande refusée avec succès');
      },
      error: (e) => {
        this.notificationService.showError('Une erreur est survenue');
      },
    });
  }

  public claimedStructure(_event: boolean): void {
    this.isClaimedStructure = !this.isClaimedStructure;
  }
}
