import { Component, EventEmitter, Input, OnInit, Output } from '@angular/core';
import { UntypedFormGroup } from '@angular/forms';
import { Structure } from '../../../../models/structure.model';
import { Module } from '../../../../structure-list/models/module.model';
import { RecapsType } from '../../enums/recapsType.enum';

@Component({
  selector: 'app-mediation-recap',
  templateUrl: './mediation-recap.component.html',
  styleUrls: ['./mediation-recap.component.scss'],
})
export class MediationRecapComponent implements OnInit {
  @Input() form: UntypedFormGroup;
  @Input() recapType: RecapsType;
  @Output() checkValidation = new EventEmitter<any>();

  public needs: Module[];
  public structuresToPrint: Structure[];
  public orientator: { structureName: string; structureMail: string; structurePhone: string };
  public comment: string;
  public beneficiary: any;
  public date: any;
  public language: string;

  ngOnInit(): void {
    this.checkValidation.emit();
    this.needs = this.form.get('filters').value;
    this.beneficiary = {
      name: this.form.get('name').value,
      surname: this.form.get('surname').value,
    };
    switch (this.recapType) {
      case RecapsType.onlineMediation:
        this.handleOnlineMediationRecap();
        break;
      case RecapsType.structure:
        this.handleStructureRecap();
        break;
      default:
        throw new Error(`Not implemented recap type ${this.recapType}`);
    }
  }

  public handleStructureRecap(): void {
    this.comment = this.form.get('comments').value;
    this.structuresToPrint = this.form.get('structureChoice').value;
    this.orientator = this.form.get('structureOrientator').value;
  }

  public isOrientator(): boolean {
    return this.orientator?.structureName ? true : false;
  }

  public handleOnlineMediationRecap(): void {
    this.date = {
      day: this.form.get('dateSlot').value.day,
      hours: this.form.get('dateSlot').value.hours.replace('-', ' et '),
    };
    this.language = this.form.get('preferredLanguage').value;
  }
}
