import { Component, EventEmitter, Input, OnInit, Output } from '@angular/core';
import { UntypedFormGroup } from '@angular/forms';
import { Structure } from '../../../../models/structure.model';
import { User } from '../../../../models/user.model';
import { StructureService } from '../../../../services/structure.service';
import { Utils } from '../../../../utils/utils';

@Component({
  selector: 'app-structure-orientator',
  templateUrl: './structure-orientator.component.html',
  styleUrls: ['./structure-orientator.component.scss'],
})
export class StructureOrientatorComponent implements OnInit {
  @Input() form: UntypedFormGroup;
  @Input() profile: User;
  @Output() validatePage = new EventEmitter<boolean>();
  public structuresLinked: Structure[] = [];
  public hasStructures: boolean = false;
  public selected: Structure;
  constructor(private structureService: StructureService, private utils: Utils) {}

  ngOnInit(): void {
    this.form = this.form.get('structureOrientator') as UntypedFormGroup;
    if (this.profile?.structuresLink?.length) {
      this.hasStructures = true;
      for (let structure of this.profile.structuresLink) {
        this.structureService.getStructure(structure).subscribe((_structure) => {
          this.structuresLinked.push(new Structure(_structure));
          if (this.form.get('structureName')?.value === _structure.structureName) {
            this.select(_structure);
          }
        });
      }
    } else {
      this.hasStructures = false;
    }
  }

  public select(structure: Structure): void {
    this.selected = structure;
    this.form.patchValue({
      structureName: structure.structureName,
      structureMail: structure.contactMail,
      structurePhone: structure.contactPhone,
    });
    this.validatePage.emit(this.form.valid);
  }

  public updatedForm(field: string, value: string) {
    if (field === 'phone') {
      this.utils.modifyPhoneInput(this.form, 'phone', value);
    } else this.form.get(field).patchValue(value);

    this.validatePage.emit(this.form.valid);
  }
}
