import { Component, EventEmitter, Input, OnChanges, Output } from '@angular/core';
import { UntypedFormGroup } from '@angular/forms';
import { Structure } from '../../../models/structure.model';
import { User } from '../../../models/user.model';
import { Filter } from '../../../structure-list/models/filter.model';
import { RecapsType } from '../enums/recapsType.enum';
import { StructuresListSteps } from '../enums/structuresListSteps.enum';

@Component({
  selector: 'app-orientation-structure-list',
  templateUrl: './orientation-structure-list.component.html',
})
export class OrientationStructureListComponent implements OnChanges {
  @Input() currentStep: StructuresListSteps;
  @Input() profile: User;
  @Input() form: UntypedFormGroup;
  @Input() filters: Filter[] = [];
  @Output() validatePage = new EventEmitter<any>();
  // Enum
  public structuresListStepsEnum = StructuresListSteps;
  public recapsType = RecapsType;
  // Init data for form
  public selectedStructures: Structure[] = [];

  ngOnChanges(): void {
    this.validatePage.emit();
  }

  public radioChange(event: { name: string; value: boolean }): void {
    const { name, value } = event;
    this.form.get(name).setValue(value);
    this.manuallySetOfPmr(event);
  }

  public checkValidation(event?: any): void {
    // Reset value of selected structure in case of multiple previous
    if (this.currentStep === StructuresListSteps.address) {
      this.selectedStructures = [];
    }
    if (this.currentStep === StructuresListSteps.structureChoice) {
      this.selectedStructures = event;
      this.form.get('structureChoice').setValue(event);
    }
    if (this.currentStep === StructuresListSteps.structureOrientator) {
      this.validatePage.emit(event);
      return;
    }
    this.validatePage.emit(event);
  }

  private manuallySetOfPmr(event: { name: string; value: boolean }): void {
    // Handle special PMR access case
    if (event.name === 'pmrAccess') {
      if (event.value) {
        this.filters.push(new Filter('pmrAccess', 'True', 'PMR'));
      } else {
        this.filters = this.filters.filter((module) => module.name !== 'pmrAccess');
      }
    }
    this.checkValidation();
  }
}
