import { PersonalOffer } from './../models/personalOffer.model';
import { Injectable } from '@angular/core';
import { ActivatedRouteSnapshot, Resolve, Router } from '@angular/router';
import { forkJoin, Observable, Subject } from 'rxjs';
import { catchError, map } from 'rxjs/operators';
import { PersonalOfferService } from '../services/personal-offer.service';
import { SearchService } from '../structure-list/services/search.service';
import { Utils } from '../utils/utils';

@Injectable()
export class PersonalOfferResolver implements Resolve<PersonalOffer> {
  public subject: Subject<PersonalOffer> = new Subject();

  constructor(
    private personalOfferService: PersonalOfferService,
    private searchService: SearchService,
    private router: Router,
    public utils: Utils
  ) {}

  resolve(route: ActivatedRouteSnapshot): Observable<PersonalOffer> {
    const personalOfferId = route.params.id;

    if (personalOfferId) {
      forkJoin({
        personalOffer: this.personalOfferService.getPersonalOffer(personalOfferId).pipe(
          map((res) => res),
          catchError(() => {
            this.router.navigate(['/home']);
            return new Observable<PersonalOffer>();
          })
        ),
        categories: this.searchService.getCategories(),
      }).subscribe((res) => {
        const personalOffer = this.utils.setServiceCategories(res.categories, res.personalOffer) as PersonalOffer;
        this.setSubject(personalOffer);
      });

      return this.getSubject();
    }
  }

  setSubject(personalOffer: PersonalOffer): void {
    this.subject.next(personalOffer);
  }

  getSubject(): Observable<PersonalOffer> {
    return this.subject.asObservable();
  }
}
