import { HttpClient } from '@angular/common/http';
import { Injectable } from '@angular/core';
import { Observable } from 'rxjs';
import { map } from 'rxjs/operators';
import { SearchQuery, SearchResults } from '../../annuaire/models/searchQuery.model';
import { Category } from '../models/category.model';
import { Module } from '../models/module.model';

@Injectable({
  providedIn: 'root',
})
export class SearchService {
  public annuaireSearchQuery: SearchQuery;
  public checkedFilterList: string[] = [];

  constructor(private http: HttpClient) {}

  /**
   * Return repository data for search
   * @returns {Category[]}
   */
  public getCategories(): Observable<Category[]> {
    return this.http.get('/api/categories').pipe(map((data: any[]) => data.map((item) => new Category(item))));
  }

  public getJobs(): Observable<string[]> {
    return this.http.get('/api/jobs').pipe(map((data: any[]) => data.map((item) => item.name)));
  }
  public getEmployers(): Observable<string[]> {
    return this.http.get('/api/employer').pipe(map((data: any[]) => data.map((item) => item.name)));
  }
  public searchUserRegistry(
    searchTerm: string,
    page: number,
    jobs?: string[],
    employers?: string[]
  ): Observable<SearchResults> {
    return this.http
      .post<any>(`/api/userRegistry/?search=${searchTerm}`, { job: jobs, employer: employers, page: page })
      .pipe();
  }
  public getUserRegistryCount(): Observable<number> {
    return this.http.get<any>(`/api/userRegistry/count`).pipe();
  }
  public getIndex(array: Module[], id: string, categ: string): number {
    return array.findIndex((m: Module) => m.id === id && m.name === categ);
  }
}
